/*
 * Copyright 2023 by DTV-Verkehrsconsult, Aachen
 *
 * This file is part of de.bsvrz.ars.ars.
 *
 * de.bsvrz.ars.ars is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.ars.ars is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.ars.ars.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * DTV-Verkehrsconsult GmbH
 * Pascalstraße 53
 * 52076 Aachen, Germany
 * phone: +49 2408 7047 0
 * mail: <info@dtv-verkehrsconsult.de>
 */
package de.bsvrz.ars.ars.mgmt.tasks.base;

/**
 * Funktionales Interface für auszuführende Tasks für den {@link TaskManager}, die im gegensatz zu {@link TaskExecutor}
 * ein Ergebnis produzieren
 *
 * @param <T> Generischer Fehlertyp, den der Task wirft
 * @param <R> Ergebnistyp
 */
public interface TaskProducer<R, T extends Exception> {

	/**
	 * Führt den Task aus und berechnet das Ergebnis
	 * @param tpi Hierüber kann der Task Fortschrittsmeldungen publizieren
	 * @throws T Generischer Fehlertyp, den der Task wirft
	 * @return Ergebnis
	 */
	R run(TaskProgressInterface tpi) throws T;

}
